package com.yanzhu.jh.project.mapper;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectMeasure;

/**
 * 实测实量Mapper接口
 * 
 * @author JiangYuQi
 * @date 2023-08-22
 */
public interface SurProjectMeasureMapper 
{
    /**
     * 查询实测实量
     * 
     * @param id 实测实量主键
     * @return 实测实量
     */
    public SurProjectMeasure selectSurProjectMeasureById(Long id);

    /**
     * 查询实测实量列表
     * 
     * @param surProjectMeasure 实测实量
     * @return 实测实量集合
     */
    public List<SurProjectMeasure> selectSurProjectMeasureList(SurProjectMeasure surProjectMeasure);

    /**
     * 新增实测实量
     * 
     * @param surProjectMeasure 实测实量
     * @return 结果
     */
    public int insertSurProjectMeasure(SurProjectMeasure surProjectMeasure);

    /**
     * 修改实测实量
     * 
     * @param surProjectMeasure 实测实量
     * @return 结果
     */
    public int updateSurProjectMeasure(SurProjectMeasure surProjectMeasure);

    /**
     * 删除实测实量
     * 
     * @param id 实测实量主键
     * @return 结果
     */
    public int deleteSurProjectMeasureById(Long id);

    /**
     * 批量删除实测实量
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurProjectMeasureByIds(Long[] ids);

    public List<SurProjectMeasure> groupMeasureInfo(SurProjectMeasure where);
}
